==> v2022.05.zip: oxo/oxo/cli.py <==
import typing as t
from pathlib import Path

import typer

from oxo import __version__, api

app = typer.Typer()

BASE_URL = typer.Option("https://0x0.st", envvar="OXO_BASE_URL")


def version_callback(value: bool):
    if value:
        typer.echo(f"{__version__}")
        raise typer.Exit()


@app.callback()
def main(
    version: t.Optional[bool] = typer.Option(
        None,
        "--version",
        callback=version_callback,
        is_eager=True,
        help="Show the version and exit.",
    ),
):
    """A command line utility for 0x0.st compliant pastebins.

    To use a different 0x0 site, set `OXO_BASE_URL` in your environment,
    or specify it in the relevant subcommand.
    """


@app.command()
def files(
    files: t.List[Path] = typer.Argument(
        ..., min=1, exists=True, file_okay=True, dir_okay=False, resolve_path=True
    ),
    base_url: str = BASE_URL,
):
    """Upload one or more files."""
    typer.echo(api.files(base_url, files))


@app.command()
def repost(urls: t.List[str] = typer.Argument(..., min=1), base_url=BASE_URL):
    """Repost one or more urls."""
    typer.echo(api.repost(base_url, urls))


@app.command()
def shorten(urls: t.List[str] = typer.Argument(..., min=1), base_url=BASE_URL):
    """Shorten one or more urls."""
    if base_url == BASE_URL.default:
        typer.secho(
            f"Warning: shortening is often disabled "
            f"for {BASE_URL.default}, command may fail",
            fg=typer.colors.RED,
        )
    typer.echo(api.shorten(base_url, urls))

==> v2022.06.zip: oxo/oxo/cli.py <==
import typing as t
from pathlib import Path

import typer

from oxo import __version__, api

app = typer.Typer()

BASE_URL = typer.Option("https://0x0.st", envvar="OXO_BASE_URL")


def version_callback(value: bool):
    if value:
        typer.echo(f"{__version__}")
        raise typer.Exit()


@app.callback()
def main(
    version: t.Optional[bool] = typer.Option(
        None,
        "--version",
        callback=version_callback,
        is_eager=True,
        help="Show the version and exit.",
    ),
):
    """A command line utility for 0x0.st compliant pastebins.

    To use a different 0x0 site, set `OXO_BASE_URL` in your environment,
    or specify it in the relevant subcommand.
    """


@app.command()
def files(
    files: t.List[Path] = typer.Argument(
        ..., min=1, exists=True, file_okay=True, dir_okay=False, resolve_path=True
    ),
    base_url: str = BASE_URL,
):
    """Upload one or more files."""
    typer.echo(api.files(base_url, files))


@app.command()
def repost(urls: t.List[str] = typer.Argument(..., min=1), base_url=BASE_URL):
    """Repost one or more urls."""
    typer.echo(api.repost(base_url, urls))


@app.command()
def shorten(urls: t.List[str] = typer.Argument(..., min=1), base_url=BASE_URL):
    """Shorten one or more urls."""
    if base_url == BASE_URL.default:
        typer.secho(
            f"Warning: shortening is often disabled "
            f"for {base_url}, command may fail",
            fg=typer.colors.RED,
            err=True,
        )
    typer.echo(api.shorten(base_url, urls))
